@@ -1,6 +1,6 @@
 package Map::Tube;
 
-$Map::Tube::VERSION   = '3.90';
+$Map::Tube::VERSION   = '3.91';
 $Map::Tube::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube - Lightweight Routing Framework.
 
 =head1 VERSION
 
-Version 3.90
+Version 3.91
 
 =cut
 
@@ -812,7 +812,7 @@ sub _get_shortest_route {
             my $links = [ split /\,/, $f_node->{link} ];
             while (scalar(@$links) > 0) {
                 my ($success, $link) = $self->_get_next_link($from, $seen, $links);
-                $success or ($links = [ grep(!/\b$link\b/, @$links) ]) and next;
+                $success or ($links = [ grep(!/\b\Q$link\E\b/, @$links) ]) and next;
 
                 if (($self->_get_length($link) == 0) || ($length > ($index + 1))) {
                     $self->_set_length($link, $length + 1);
@@ -821,13 +821,13 @@ sub _get_shortest_route {
                 }
 
                 $seen->{$link} = 1;
-                $links = [ grep(!/\Q\b$link\b\E/, @$links) ];
+                $links = [ grep(!/\b\Q$link\E\b/, @$links) ];
             }
         }
 
         $index = $length + 1;
         $from  = shift @$nodes;
-        $nodes = [ grep(!/\Q\b$from\b\E/, @$nodes) ] if defined $from;
+        $nodes = [ grep(!/\b\Q$from\E\b/, @$nodes) ] if defined $from;
     }
 }
 
